@@ -14,9 +14,9 @@ use itertools::Itertools;
 use crate::{all_imports::RInts, pyo3_prelude::*, sv, util::BitMask128};
 
 use super::{
-    circuit_optimizer::OptimizationContext, computational_node::EinsumArgs, evaluate_fn,
-    prelude::*, py_circuit_items::PY_CIRCUIT_ITEMS, Add, Concat, Einsum, GeneralFunction,
-    HashBytes, Index, Rearrange, ScalarConstant, Scatter, Symbol,
+    circuit_optimizer::OptimizationContext, computational_node::EinsumArgs, prelude::*,
+    py_circuit_items::PY_CIRCUIT_ITEMS, Add, Concat, Einsum, GeneralFunction, HashBytes, Index,
+    Rearrange, ScalarConstant, Scatter, Symbol,
 };
 use crate::{
     filter_by_variant,
@@ -1051,34 +1051,6 @@ pub fn rearrange_fuse(node: &Rearrange) -> Option<Rearrange> {
             .ok()
     })
 }
-/// this does less than python version, maybe should expand
-#[pyfunction]
-pub fn generalfunction_evaluate_simple(node: &GeneralFunction) -> Option<CircuitRc> {
-    if !node.nodes.is_empty()
-        || node.spec.num_non_batchable_output_dims != 0
-        || !node.spec.is_batchable()
-    {
-        return None;
-    }
-    node.nodes[0].as_scalar_constant().map(|_inner| {
-        Python::with_gil(|py| {
-            ScalarConstant::new(
-                evaluate_fn(&Circuit::GeneralFunction(node.clone()))
-                    .unwrap()
-                    .tensor()
-                    .getattr(py, "item")
-                    .unwrap()
-                    .call(py, (), None)
-                    .unwrap()
-                    .extract(py)
-                    .unwrap(),
-                sv![],
-                node.name_cloned(),
-            )
-            .rc()
-        })
-    })
-}
 
 // #[pyfunction]
 // pub fn push_down_index_small(node:&Index)->Option<CircuitRc>{
