@@ -247,10 +247,6 @@ impl Symbol {
         out.info.shape = shape;
         out.init_info().unwrap()
     }
-
-    pub fn new_with_random_uuid(shape: Shape, name: Option<String>) -> Self {
-        Self::new(shape, Uuid::new_v4(), name)
-    }
 }
 
 #[pymethods]
@@ -265,6 +261,14 @@ impl Symbol {
     fn uuid(&self) -> PyUuid {
         PyUuid(self.uuid)
     }
+    #[staticmethod]
+    pub fn new_with_random_uuid(shape: Shape, name: Option<String>) -> Self {
+        Self::new(shape, Uuid::new_v4(), name)
+    }
+    #[staticmethod]
+    pub fn new_with_none_uuid(shape: Shape, name: Option<String>) -> Self {
+        Self::new(shape, Uuid::nil(), name)
+    }
 }
 
 #[pyclass(extends=PyCircuitBase, unsendable)]
