@@ -1,10 +1,10 @@
-use crate::hashmaps::FxHashMap as HashMap;
+use crate::{hashmaps::FxHashMap as HashMap, timed};
 
 use super::{
     circuit_utils::{count_nodes, toposort_circuit, total_flops},
     prelude::*,
     repr::ReprWrapper,
-    repr::RustRepr,
+    repr::{repr_op_string, rustfmt_string, RustRepr},
     HashBytes,
 };
 use base16::encode_lower;
@@ -56,7 +56,16 @@ pub fn repr_circuit_deep_compiler(circuit: &Circuit) -> String {
                 Circuit::Scatter(scatter) => format!("{}", scatter.index),
                 Circuit::Concat(concat) => concat.axis.to_string(),
                 Circuit::GeneralFunction(gf) => gf.spec.name.clone(),
-                Circuit::Symbol(sy) => format!("{}", &sy.uuid),
+                Circuit::Symbol(sy) => {
+                    if sy.uuid.is_nil() {
+                        "".to_owned()
+                    } else {
+                        format!("{}", &sy.uuid)
+                    }
+                }
+                Circuit::ModuleNode(mn) => {
+                    format!("{}", &mn.spec.name.as_ref().unwrap_or(&"".to_owned()))
+                }
                 _ => "".to_owned(),
             }
         });
@@ -118,7 +127,7 @@ pub fn repr_circuit_one_level(
                 "Einsum::nrc({}, {}, {})",
                 einargs,
                 e.out_axes.repr(),
-                e.name_cloned().repr()
+                repr_op_string(&e.name_cloned())
             )
         }
         Circuit::ArrayConstant(a) => {
@@ -126,7 +135,7 @@ pub fn repr_circuit_one_level(
                 format!(
                     "ArrayConstant::randn_seeded({}, {}, {}, {}).rc()",
                     a.info().shape.repr(),
-                    a.name_cloned().repr(),
+                    repr_op_string(&a.name_cloned()),
                     a.info().device_dtype.repr(),
                     a.value.hash_usize().unwrap(),
                 )
@@ -134,7 +143,7 @@ pub fn repr_circuit_one_level(
                 let hash_base16 = a.save_rrfs().unwrap();
                 format!(
                     "ArrayConstant::from_hash({},{}).unwrap().rc()",
-                    a.name_cloned().repr(),
+                    repr_op_string(&a.name_cloned()),
                     (&hash_base16 as &str).repr(),
                 )
             }
@@ -143,20 +152,20 @@ pub fn repr_circuit_one_level(
             "Symbol::nrc({}, {}, {})",
             s.info().shape.repr(),
             s.uuid.repr(),
-            s.name_cloned().repr()
+            repr_op_string(&s.name_cloned())
         ),
         Circuit::ScalarConstant(s) => format!(
             "ScalarConstant::nrc({}, {}, {})",
             s.value.repr(),
             s.info().shape.repr(),
-            s.name_cloned().repr()
+            repr_op_string(&s.name_cloned())
         ),
         Circuit::Add(a) => {
             let variable_names: Vec<String> = a.children().map(|c| node_string(&c)).collect();
             format!(
                 "Add::nrc(vec![{}], {})",
                 variable_names.join(", "),
-                a.name_cloned().repr()
+                repr_op_string(&a.name_cloned())
             )
         }
         Circuit::Rearrange(r) => {
@@ -164,7 +173,7 @@ pub fn repr_circuit_one_level(
                 "Rearrange::nrc({}, {}, {})",
                 node_string(&r.node),
                 r.spec.repr(),
-                r.name_cloned().repr()
+                repr_op_string(&r.name_cloned())
             )
         }
         Circuit::Index(i) => format!(
@@ -175,7 +184,7 @@ pub fn repr_circuit_one_level(
                 &i.info().device_dtype,
                 tensors_as_randn
             ),
-            i.name_cloned().repr()
+            repr_op_string(&i.name_cloned())
         ),
         Circuit::GeneralFunction(g) => {
             if g.spec.is_official {
@@ -184,7 +193,7 @@ pub fn repr_circuit_one_level(
                     "GeneralFunction::new_by_name(vec![{}], {}, {}).unwrap().rc()",
                     variable_names.join(", "),
                     g.spec.name.repr(),
-                    g.name_cloned().repr()
+                    repr_op_string(&g.name_cloned())
                 )
             } else {
                 panic!(
@@ -199,7 +208,7 @@ pub fn repr_circuit_one_level(
                 "Concat::nrc(vec![{}], {}, {})",
                 variable_names.join(", "),
                 c.axis,
-                c.name_cloned().repr()
+                repr_op_string(&c.name_cloned())
             )
         }
         Circuit::Scatter(s) => {
@@ -213,9 +222,23 @@ pub fn repr_circuit_one_level(
                     tensors_as_randn
                 ),
                 s.info().shape.repr(),
-                s.name_cloned().repr()
+                repr_op_string(&s.name_cloned())
             )
         }
+        Circuit::ModuleNode(mn) => {
+            format!(
+                "ModuleNode::nrc(vec![{}],{},{})",
+                mn.children()
+                    .map(|x| node_string(&x))
+                    .collect::<Vec<_>>()
+                    .join(", "),
+                mn.spec.repr(),
+                repr_op_string(&mn.name_cloned())
+            )
+        }
+        _ => {
+            unimplemented!()
+        }
     }
 }
 
@@ -279,6 +302,7 @@ pub fn rust_expression_notation_circuit(circuit: CircuitRc, tensors_as_randn: bo
     }
     source.push('}');
     source
+    // timed!(rustfmt_string(&source))
 }
 
 pub fn print_circuit_stats(circuit: &Circuit) {
