@@ -1,5 +1,6 @@
 use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use std::cmp::max;
+use std::ops::Sub;
 
 use z3;
 
@@ -138,9 +139,10 @@ pub fn schedule_dag_strategy_ints(
     verbose: usize,
     mem_limit: usize,
     num_mem_chunks: usize,
+    timeout: usize,
 ) -> Result<Vec<usize>, SchedulingError> {
     let mut cfg = Config::new();
-    cfg.set_timeout_msec(5_000);
+    cfg.set_timeout_msec(timeout as u64);
     let ctx = Context::new(&cfg);
     let opt = Solver::new(&ctx);
 
@@ -153,6 +155,7 @@ pub fn schedule_dag_strategy_ints(
         .collect();
     let outputs = dag.get_outputs();
     let zero = Int::from_u64(ctx_ref, 0);
+    let one = Int::from_u64(ctx_ref, 1);
     let time_end = Int::from_u64(ctx_ref, (n_time_slots - 1) as u64);
     let end_times: Vec<Int> = (0..dag.node_costs.len())
         .map(|i| {
@@ -205,7 +208,6 @@ pub fn schedule_dag_strategy_ints(
     };
     timed!(add_constraints(), 10, verbose >= 2);
 
-    // opt.minimize(&tend);
     timed!(opt.check(), 10, verbose >= 2);
     opt.get_model()
         .map(|model| {
@@ -218,6 +220,9 @@ pub fn schedule_dag_strategy_ints(
                 })
                 .collect();
             start_steps.sort();
+            if verbose >= 5 {
+                dbg!(&start_steps);
+            }
             start_steps.iter().map(|x| x.1).collect()
         })
         .ok_or_else(|| {
