@@ -154,6 +154,18 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(concat_elim_identity, m)?)?;
     m.add_function(wrap_pyfunction!(concat_merge_uniform, m)?)?;
     m.add_function(wrap_pyfunction!(generalfunction_pull_removable_axes, m)?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::generalfunction_merge_inverses,
+        m
+    )?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::generalfunction_special_case_simplification,
+        m
+    )?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::generalfunction_rewrite::generalfunction_evaluate_simple,
+        m
+    )?)?;
     m.add_function(wrap_pyfunction!(concat_pull_removable_axes, m)?)?;
     m.add_function(wrap_pyfunction!(einsum_pull_removable_axes, m)?)?;
     m.add_function(wrap_pyfunction!(add_make_broadcasts_explicit, m)?)?;
