@@ -550,9 +550,6 @@ pub fn compose(top: &TensorIndex, bottom: &TensorIndex) -> Option<TensorIndex> {
                 let top_here = top.0[top_idx].clone();
                 top_idx += 1;
                 Python::with_gil(|py| {
-                    dbg!(top, bottom);
-                    let z: Option<bool> = pycall!(PY_UTILS.print, (top.clone(),));
-                    let z: Option<bool> = pycall!(PY_UTILS.print, (bottom.clone(),));
                     let indexed_tensor = t.clone().py_getitem(py, top_here).unwrap();
                     if indexed_tensor.shape().is_empty() {
                         result.push(TensorAxisIndex::Single(pycall!(
@@ -620,28 +617,6 @@ pub fn compose(top: &TensorIndex, bottom: &TensorIndex) -> Option<TensorIndex> {
     Some(TensorIndex(result))
 }
 
-pub fn cuda_to_first_cuda(string: &str) -> String {
-    if string == "cuda" {
-        let number = match std::env::var("CUDA_VISIBLE_DEVICES") {
-            Err(_e) => 0,
-            Ok(s) => s
-                .split(",")
-                .map(|s| s.parse::<usize>())
-                .nth(0)
-                .unwrap_or(Ok(0))
-                .unwrap_or(0),
-        };
-        format!("cuda:{}", number)
-    } else {
-        string.to_owned()
-    }
-}
-
-#[test]
-fn test_cvd() {
-    dbg!(cuda_to_first_cuda("cuda"));
-}
-
 /// use string so you can compare fast when constructing and have full range (weird types like uint or bfloat16)
 /// as opposed to PyObject torch.dtype or enum (could switch to enum)
 #[pyclass]
@@ -664,10 +639,7 @@ impl TorchDeviceDtypeOp {
     #[new]
     #[args(device = "None", dtype = "None")]
     fn new(device: Option<String>, dtype: Option<String>) -> Self {
-        Self {
-            device: device.map(|x| cuda_to_first_cuda(&x)),
-            dtype,
-        }
+        Self { device, dtype }
     }
 }
 
@@ -684,10 +656,7 @@ pub struct TorchDeviceDtype {
 impl TorchDeviceDtype {
     #[new]
     fn new(device: String, dtype: String) -> Self {
-        Self {
-            device: cuda_to_first_cuda(&device),
-            dtype,
-        }
+        Self { device, dtype }
     }
     #[staticmethod]
     #[pyo3(name = "from_tensor")]
